@@ -30,10 +30,12 @@ def retry(func):
 
 
 headers = {
-    "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/96.0.4664.110 Safari/537.36",
-    "cookie": shindan_config.shindanmaker_cookie,
+    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/96.0.4664.110 Safari/537.36"
 }
 
+if shindan_config.shindanmaker_cookie:
+    headers["cookie"] = shindan_config.shindanmaker_cookie
+
 
 @retry
 async def get(client: httpx.AsyncClient, url: str, **kwargs):
